var i;
var _loop = function (_i) {
  (function () {
    return _i;
  });
};
for (var _i = 4; _i < 6; _i++) {
  _loop(_i);
}
